eric7/eric7.py

branch
eric7
changeset 8356
68ec9c3d4de5
parent 8354
12ebd3934fef
child 8358
144a6b854f70
--- a/eric7/eric7.py	Sat May 22 17:01:51 2021 +0200
+++ b/eric7/eric7.py	Sat May 22 18:51:46 2021 +0200
@@ -79,7 +79,7 @@
 sys.path.insert(2, os.path.join(os.path.dirname(__file__),
                                 "DebugClients", "Python"))
 
-from E5Gui.E5Application import E5Application
+from E5Gui.EricApplication import EricApplication
 
 
 def handleSingleApplication(ddindex):
@@ -88,9 +88,9 @@
     
     @param ddindex index of a '--' option in the options list
     """
-    from E5Gui.E5SingleApplication import E5SingleApplicationClient
+    from E5Gui.EricSingleApplication import EricSingleApplicationClient
     
-    client = E5SingleApplicationClient()
+    client = EricSingleApplicationClient()
     res = client.connect()
     if res > 0:
         if (
@@ -294,7 +294,7 @@
     # set the library paths for plugins
     Startup.setLibraryPaths()
 
-    app = E5Application(sys.argv)
+    app = EricApplication(sys.argv)
     ddindex = Startup.handleArgs(sys.argv, appinfo)
     
     logging.debug("Importing Preferences")
@@ -386,8 +386,8 @@
     initSSL()
     
     splash.showMessage(QCoreApplication.translate("eric7", "Starting..."))
     # We can only import these after creating the E5Application because they
     # make Qt calls that need the E5Application to exist.
     from UI.UserInterface import UserInterface
 
     splash.showMessage(
@@ -401,8 +401,8 @@
     QTimer.singleShot(0, uiStartUp)
     
     # generate a graphical error handler
-    from E5Gui import E5ErrorMessage
-    eMsg = E5ErrorMessage.qtHandler()
+    from E5Gui import EricErrorMessage
+    eMsg = EricErrorMessage.qtHandler()
     eMsg.setMinimumSize(600, 400)
     
     # start the event loop
@@ -386,8 +386,8 @@
     
     splash.showMessage(QCoreApplication.translate("eric7", "Starting..."))
-    # We can only import these after creating the E5Application because they
-    # make Qt calls that need the E5Application to exist.
+    # We can only import these after creating the EricApplication because they
+    # make Qt calls that need the EricApplication to exist.
     from UI.UserInterface import UserInterface
 

eric ide

mercurial